<?php

namespace EMS\PortalFuncionario\Geral\Controllers;

use EMS\PortalFuncionario\Geral\Services\DocumentoService;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO\Response\Error;

class DocumentoController {
    /** @var DocumentoService */
    protected $documentoService;

    public function __construct(
        DocumentoService $documentoService
    ) {
        $this->documentoService = $documentoService;
    }

    public function getDocumentosVinculo(
        Request\Filter $request,
        Response $response
    ) {
        try {
            $row = $request->getParameters();

            $nrOrg     = (int) $row['NRORG'];
            $nrVinculo = (int) $row['NRVINCULOM'];

            $nrCategoria = isset($row['NRCATEGDOCUMENTO']) ?
                (string) $row['NRCATEGDOCUMENTO'] :
                null;

            $documentos = $this->documentoService->getDocumentosVinculo(
                $nrOrg, $nrVinculo, $nrCategoria
            );

            $response->addDataSet(new DataSet('data', $documentos));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }

    public function getCategoriasComDocumentoVinculo(
        Request\Filter $request,
        Response $response
    ) {
        try {
            $row = $request->getParameters();

            $nrOrg     = (int) $row['NRORG'];
            $nrVinculo = (int) $row['NRVINCULOM'];

            $categorias = $this->documentoService->getCategoriasComDocumentoVinculo(
                $nrOrg, $nrVinculo
            );

            $response->addDataSet(new DataSet('data', $categorias));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }

    public function getCategorias(
        Request\Filter $request,
        Response $response
    ) {
        try {
            $row = $request->getParameters();

            $nrOrg     = (int) $row['NRORG'];

            $categorias = $this->documentoService->getCategorias(
                $nrOrg
            );

            $response->addDataSet(new DataSet('data', $categorias));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }

    public function getTipos(
        Request\Filter $request,
        Response $response
    ) {
        try {
            $row = $request->getParameters();

            $nrOrg = (int) $row['NRORG'];

            $tipos = $this->documentoService->getTipos(
                $nrOrg
            );

            $response->addDataSet(new DataSet('data', $tipos));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }

    public function downloadDocumento(
        Request\Filter $request,
        Response       $response
    ) {
        try {
            $row = $request->getParameters();

            $nrOrg   = (int) $row['NRORG'];
            $nrAnexo = (int) $row['NRANEXO'];

            $file = $this->documentoService->downloadDocumento(
                $nrOrg, $nrAnexo
            );

            $response->addDataSet(new DataSet('data', $file));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }

    public function saveDocumento(
        Request\Row $request,
        Response       $response
    ) {
        try {
            $row = $request->getRow()->getArrayCopy();

            $success = $this->documentoService->saveDocumento(
                $row
            );

            $dataset = [
                'success' => $success
            ];

            $response->addDataSet(new DataSet('data', $dataset));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }

    public function getAssinaturasVinculo(
        Request\Filter $request,
        Response $response
    ) {
        try {
            $row = $request->getParameters();

            $nrOrg     = (int) $row['NRORG'];
            $nrVinculo = (int) $row['NRVINCULOM'];
            $nrperiodoapuracao = (int) $row['NRPERIODOAPURACAO'];

            $relatorios = $this->documentoService->getAssinaturasVinculo(
                $nrOrg, $nrVinculo, $nrperiodoapuracao
            );

            $response->addDataSet(new DataSet('data', $relatorios));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }

    public function getAssinaturaByVinculo(
        Request\Filter $request,
        Response $response
    ) {
        try {
            $row = $request->getParameters();

            $nrOrg     = (int) $row['NRORG'];
            $nrVinculo = (int) $row['NRVINCULOM'];

            $categorias = $this->documentoService->getAssinaturaByVinculo(
                $nrOrg, $nrVinculo
            );

            $response->addDataSet(new DataSet('data', $categorias));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }

    public function saveDocumentoAssinatura(
        Request\Row $request,
        Response       $response
    ) {
        try {
            $row = $request->getRow()->getArrayCopy();

            $success = $this->documentoService->saveDocumentoAssinatura(
                $row
            );

            $dataset = [
                'success' => $success
            ];

            $response->addDataSet(new DataSet('data', $dataset));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }

    public function saveAssinaturaVinculo(
        Request\Row $request,
        Response       $response
    ) {
        try {
            $row = $request->getRow()->getArrayCopy();

            $success = $this->documentoService->saveAssinaturaVinculo(
                $row
            );

            $dataset = [
                'success' => $success
            ];

            $response->addDataSet(new DataSet('data', $dataset));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }

    public function getIntegracaoDigitalFile(
        Request\Filter $request,
        Response $response
    ) {
        try {
            $row = $request->getParameters();

            $nrOrg               = (int) $row['NRORG'];
            $nrVinculo           = (int) $row['NRVINCULOM'];
            $nrParNegocio        = (int) $row['NRPARCNEGOCIO'];
            $nrIntegracaoDigital = (int) $row['NRINTELETRDIGIT'];

            $categorias = $this->documentoService->getIntegracaoDigitalFile(
                $nrOrg, $nrVinculo, $nrParNegocio, $nrIntegracaoDigital
            );

            $response->addDataSet(new DataSet('data', $categorias));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }

    public function changeStatusAssinatura(
        Request\Row $request,
        Response       $response
    ) {
        try {
            $row = $request->getRow()->getArrayCopy();

            $success = $this->documentoService->changeStatusAssinatura(
                $row
            );

            $dataset = [
                'success' => $success
            ];

            $response->addDataSet(new DataSet('data', $dataset));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }
}
