<?php
namespace EMS\PortalFuncionario\Geral\Services;

use Zeedhi\Framework\Controller\Crud;
use Doctrine\ORM\EntityManager;

use EMS\PortalFuncionario\Geral\Repository\EstruturaRepository;
use Ems\PortalFuncionario\Util\HcmServices;

class EstruturaService extends Crud {
    /** @var Entitymanager */
    protected $entityManager;

    /** @var EstruturaRepository */
    protected $estruturaRepository;

    /** @var HcmServices */
    protected $hcmServices;

    public const ESTRUTURA_GERENCIAL    = 'NRESTRUTGEREN';
    public const ESTRUTURA_LEGAL        = 'NRESTRUTLEGAL';

    public const DEFAULT_ESTRUTURA_PONTO_ACESSO     = self::ESTRUTURA_GERENCIAL;
    public const SECONDARY_ESTRUTURA_PONTO_ACESSO   = self::ESTRUTURA_LEGAL;

    public function __construct(
        EntityManager $entityManager,
        EstruturaRepository $estruturaRepository,
        HcmServices $hcmServices
    ) {
        $this->entityManager        = $entityManager;
        $this->estruturaRepository  = $estruturaRepository;
        $this->hcmServices          = $hcmServices;
    }

    public function getPontoAcesso(string $nrorg, string $nrvinculom) : array {
        try {
            return $this->estruturaRepository->getPontoAcesso($nrorg, $nrvinculom);
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function getEstrutura(
        int $nrOrg,
        string $nmTipo
    ): array {
        $route = 'getEstrutura';

        $params = [
            'requestType' => 'Row',
            'row' => [
                'NMTIPOESTRUTURA' => $nmTipo,
            ],
        ];

        $result = $this->hcmServices->send(
            $route, $params, $nrOrg
        );

        $estruturas = $result['dataset'][$route];

        return $estruturas;
    }
}